package util

import groovy.transform.CompileStatic
import groovy.transform.Memoized

@CompileStatic
class DockerLogin {

    static void perform() {
        loginDockerInternal()
    }

    @Memoized
    private static Object loginDockerInternal() {
        // Проверяем на всякий случай, что докер вообще установлен
        if (System.findExecutablesInPath(['docker']).isEmpty())
            throw new FileNotFoundException("Can't find installed docker-compose at that system!")

        // Логинимся в Registry
        ScriptLog.printf "Performing login to registry..."

        def registryName = CIProperties.getProperty("docker.registry")
        def registryUser = CIProperties.getProperty("docker.registry.username")
        def registryPassword = CIProperties.getProperty("docker.registry.password")

        if (registryName.isNullOrBlank()) {
            throw new IllegalStateException("Docker registry name not set")
        }
        if (registryUser.isNullOrBlank()) {
            throw new IllegalStateException("Docker registry user not set")
        }
        if (registryPassword.isNullOrBlank()) {
            throw new IllegalStateException("Docker registry password not set")
        }

        sh "docker login $registryName -u $registryUser -p $registryPassword"

        ScriptLog.printf "Login into docker registry '${registryName}' successful!"
    }
}